referrerpolicy=no-referrer-when-downgrade

TypeInfo

Trait TypeInfo 

pub trait TypeInfo {
    type Identity: 'static + ?Sized;

    // Required method
    fn type_info() -> Type;
}
Implementors return their meta type information.

Required Associated Types

type Identity: 'static + ?Sized

The type identifying for which type info is provided.

Note

This is used to uniquely identify a type via core::any::TypeId::of. In most cases it will just be Self, but can be used to unify different types which have the same encoded representation e.g. reference types Box<T>, &T and &mut T.

Required Methods

fn type_info() -> Type

Returns the static type identifier for Self.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types



impl TypeInfo for bool



type Identity = bool



fn type_info() -> Type



impl TypeInfo for char



type Identity = char



fn type_info() -> Type



impl TypeInfo for i8



type Identity = i8



fn type_info() -> Type



impl TypeInfo for i16



type Identity = i16



fn type_info() -> Type



impl TypeInfo for i32



type Identity = i32



fn type_info() -> Type



impl TypeInfo for i64



type Identity = i64



fn type_info() -> Type



impl TypeInfo for i128



type Identity = i128



fn type_info() -> Type



impl TypeInfo for str



type Identity = str



fn type_info() -> Type



impl TypeInfo for u8



type Identity = u8



fn type_info() -> Type



impl TypeInfo for u16



type Identity = u16



fn type_info() -> Type



impl TypeInfo for u32



type Identity = u32



fn type_info() -> Type



impl TypeInfo for u64



type Identity = u64



fn type_info() -> Type



impl TypeInfo for u128



type Identity = u128



fn type_info() -> Type



impl TypeInfo for ()



type Identity = ()



fn type_info() -> Type



impl TypeInfo for String



type Identity = str



fn type_info() -> Type



impl TypeInfo for NonZero<i8>



type Identity = NonZero<i8>



fn type_info() -> Type



impl TypeInfo for NonZero<i16>



type Identity = NonZero<i16>



fn type_info() -> Type



impl TypeInfo for NonZero<i32>



type Identity = NonZero<i32>



fn type_info() -> Type



impl TypeInfo for NonZero<i64>



type Identity = NonZero<i64>



fn type_info() -> Type



impl TypeInfo for NonZero<i128>



type Identity = NonZero<i128>



fn type_info() -> Type



impl TypeInfo for NonZero<u8>



type Identity = NonZero<u8>



fn type_info() -> Type



impl TypeInfo for NonZero<u16>



type Identity = NonZero<u16>



fn type_info() -> Type



impl TypeInfo for NonZero<u32>



type Identity = NonZero<u32>



fn type_info() -> Type



impl TypeInfo for NonZero<u64>



type Identity = NonZero<u64>



fn type_info() -> Type



impl TypeInfo for NonZero<u128>



type Identity = NonZero<u128>



fn type_info() -> Type



impl TypeInfo for Duration



type Identity = Duration



fn type_info() -> Type



impl TypeInfo for AccountId32



type Identity = AccountId32



fn type_info() -> Type



impl TypeInfo for AnySignature



type Identity = AnySignature



fn type_info() -> Type



impl TypeInfo for ArithmeticError



type Identity = ArithmeticError



fn type_info() -> Type



impl TypeInfo for BlakeTwo256



type Identity = BlakeTwo256



fn type_info() -> Type



impl TypeInfo for CompactProof



type Identity = CompactProof



fn type_info() -> Type



impl TypeInfo for Digest



type Identity = Digest



fn type_info() -> Type



impl TypeInfo for DigestItem



type Identity = DigestItem



fn type_info() -> Type



impl TypeInfo for DispatchError



type Identity = DispatchError



fn type_info() -> Type



impl TypeInfo for Era



type Identity = Era



fn type_info() -> Type



impl TypeInfo for Error



type Identity = Error



fn type_info() -> Type



impl TypeInfo for ExtrinsicInclusionMode



type Identity = ExtrinsicInclusionMode



fn type_info() -> Type



impl TypeInfo for FixedI64



type Identity = FixedI64



fn type_info() -> Type



impl TypeInfo for FixedI128



type Identity = FixedI128



fn type_info() -> Type



impl TypeInfo for FixedU64



type Identity = FixedU64



fn type_info() -> Type



impl TypeInfo for FixedU128



type Identity = FixedU128



fn type_info() -> Type



impl TypeInfo for H128



type Identity = H128



fn type_info() -> Type



impl TypeInfo for H160



type Identity = H160



fn type_info() -> Type



impl TypeInfo for H256



type Identity = H256



fn type_info() -> Type



impl TypeInfo for H384



type Identity = H384



fn type_info() -> Type



impl TypeInfo for H512



type Identity = H512



fn type_info() -> Type



impl TypeInfo for H768



type Identity = H768



fn type_info() -> Type



impl TypeInfo for InvalidVersion



type Identity = InvalidVersion



fn type_info() -> Type



impl TypeInfo for Keccak256



type Identity = Keccak256



fn type_info() -> Type



impl TypeInfo for KeyTypeId



type Identity = KeyTypeId



fn type_info() -> Type



impl TypeInfo for Lsb0



type Identity = Lsb0



fn type_info() -> Type



impl TypeInfo for MockCallU64



type Identity = MockCallU64



fn type_info() -> Type



impl TypeInfo for ModuleError



type Identity = ModuleError



fn type_info() -> Type



impl TypeInfo for ModuleError



type Identity = ModuleError



fn type_info() -> Type



impl TypeInfo for Msb0



type Identity = Msb0



fn type_info() -> Type



impl TypeInfo for MultiSignature



type Identity = MultiSignature



fn type_info() -> Type



impl TypeInfo for MultiSigner



type Identity = MultiSigner



fn type_info() -> Type



impl TypeInfo for OffenceSeverity



type Identity = OffenceSeverity



fn type_info() -> Type



impl TypeInfo for OpaqueExtrinsic



type Identity = OpaqueExtrinsic



fn type_info() -> Type



impl TypeInfo for OpaqueMetadata



type Identity = OpaqueMetadata



fn type_info() -> Type



impl TypeInfo for OpaqueMultiaddr



type Identity = OpaqueMultiaddr



fn type_info() -> Type



impl TypeInfo for OpaqueNetworkState



type Identity = OpaqueNetworkState



fn type_info() -> Type



impl TypeInfo for OpaquePeerId



type Identity = OpaquePeerId



fn type_info() -> Type



impl TypeInfo for OpaqueValue



type Identity = OpaqueValue



fn type_info() -> Type



impl TypeInfo for PerU16



type Identity = PerU16



fn type_info() -> Type



impl TypeInfo for Perbill



type Identity = Perbill



fn type_info() -> Type



impl TypeInfo for Percent



type Identity = Percent



fn type_info() -> Type



impl TypeInfo for Permill



type Identity = Permill



fn type_info() -> Type



impl TypeInfo for Perquintill



type Identity = Perquintill



fn type_info() -> Type



impl TypeInfo for ProofOfPossession



type Identity = ProofOfPossession



fn type_info() -> Type



impl TypeInfo for ProofOfPossession



type Identity = ProofOfPossession



fn type_info() -> Type



impl TypeInfo for ProofOfPossession



type Identity = ProofOfPossession



fn type_info() -> Type



impl TypeInfo for ProofOfPossession



type Identity = ProofOfPossession



fn type_info() -> Type



impl TypeInfo for ProofOfPossession



type Identity = ProofOfPossession



fn type_info() -> Type



impl TypeInfo for ProofOfPossession



type Identity = ProofOfPossession



fn type_info() -> Type



impl TypeInfo for Public



type Identity = Public



fn type_info() -> Type



impl TypeInfo for Public



type Identity = Public



fn type_info() -> Type



impl TypeInfo for Public



type Identity = Public



fn type_info() -> Type



impl TypeInfo for Public



type Identity = Public



fn type_info() -> Type



impl TypeInfo for Public



type Identity = Public



fn type_info() -> Type



impl TypeInfo for Public



type Identity = Public



fn type_info() -> Type



impl TypeInfo for RingVerifierKey



type Identity = [u8; 384]



fn type_info() -> Type



impl TypeInfo for RingVrfSignature



type Identity = RingVrfSignature



fn type_info() -> Type



impl TypeInfo for RuntimeVersion



type Identity = RuntimeVersion



fn type_info() -> Type



impl TypeInfo for Signature



type Identity = Signature



fn type_info() -> Type



impl TypeInfo for Signature



type Identity = Signature



fn type_info() -> Type



impl TypeInfo for Signature



type Identity = Signature



fn type_info() -> Type



impl TypeInfo for Signature



type Identity = Signature



fn type_info() -> Type



impl TypeInfo for Signature



type Identity = Signature



fn type_info() -> Type



impl TypeInfo for Signature



type Identity = Signature



fn type_info() -> Type



impl TypeInfo for StorageProof



type Identity = StorageProof



fn type_info() -> Type



impl TypeInfo for StorageProofError



type Identity = StorageProofError



fn type_info() -> Type



impl TypeInfo for TestSignature



type Identity = TestSignature



fn type_info() -> Type



impl TypeInfo for TokenError



type Identity = TokenError



fn type_info() -> Type



impl TypeInfo for TransactionalError



type Identity = TransactionalError



fn type_info() -> Type



impl TypeInfo for U128



type Identity = U128



fn type_info() -> Type



impl TypeInfo for U256



type Identity = U256



fn type_info() -> Type



impl TypeInfo for U512



type Identity = U512



fn type_info() -> Type



impl TypeInfo for UintAuthorityId



type Identity = UintAuthorityId



fn type_info() -> Type



impl TypeInfo for Void



type Identity = Void



fn type_info() -> Type



impl TypeInfo for VrfPreOutput



type Identity = [u8; 32]



fn type_info() -> Type



impl TypeInfo for VrfPreOutput



type Identity = [u8; 32]



fn type_info() -> Type



impl TypeInfo for VrfProof



type Identity = [u8; 64]



fn type_info() -> Type



impl TypeInfo for VrfSignature



type Identity = VrfSignature



fn type_info() -> Type



impl TypeInfo for VrfSignature



type Identity = VrfSignature



fn type_info() -> Type



impl<'a> TypeInfo for PiecewiseLinear<'a>
where 'a: 'static,



type Identity = PiecewiseLinear<'a>



fn type_info() -> Type



impl<A> TypeInfo for (A,)
where A: TypeInfo + 'static,



type Identity = (A,)



fn type_info() -> Type



impl<A, B> TypeInfo for (A, B)
where A: TypeInfo + 'static, B: TypeInfo + 'static,



type Identity = (A, B)



fn type_info() -> Type



impl<A, B, C> TypeInfo for (A, B, C)
where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static,



type Identity = (A, B, C)



fn type_info() -> Type



impl<A, B, C, D> TypeInfo for (A, B, C, D)
where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static,



impl<A, B, C, D, E> TypeInfo for (A, B, C, D, E)
where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static,



impl<A, B, C, D, E, F> TypeInfo for (A, B, C, D, E, F)
where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static,



impl<A, B, C, D, E, F, G> TypeInfo for (A, B, C, D, E, F, G)
where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static,



impl<A, B, C, D, E, F, G, H> TypeInfo for (A, B, C, D, E, F, G, H)
where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static,



impl<A, B, C, D, E, F, G, H, I> TypeInfo for (A, B, C, D, E, F, G, H, I)
where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static,



impl<A, B, C, D, E, F, G, H, I, J> TypeInfo for (A, B, C, D, E, F, G, H, I, J)
where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static, J: TypeInfo + 'static,



impl<A, B, C, D, E, F, G, H, I, J, K> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K)
where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static, J: TypeInfo + 'static, K: TypeInfo + 'static,



impl<A, B, C, D, E, F, G, H, I, J, K, L> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L)
where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static, J: TypeInfo + 'static, K: TypeInfo + 'static, L: TypeInfo + 'static,



impl<A, B, C, D, E, F, G, H, I, J, K, L, M> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L, M)
where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static, J: TypeInfo + 'static, K: TypeInfo + 'static, L: TypeInfo + 'static, M: TypeInfo + 'static,



impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L, M, N)
where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static, J: TypeInfo + 'static, K: TypeInfo + 'static, L: TypeInfo + 'static, M: TypeInfo + 'static, N: TypeInfo + 'static,



impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O)
where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static, J: TypeInfo + 'static, K: TypeInfo + 'static, L: TypeInfo + 'static, M: TypeInfo + 'static, N: TypeInfo + 'static, O: TypeInfo + 'static,



impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P)
where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static, J: TypeInfo + 'static, K: TypeInfo + 'static, L: TypeInfo + 'static, M: TypeInfo + 'static, N: TypeInfo + 'static, O: TypeInfo + 'static, P: TypeInfo + 'static,



impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q)
where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static, J: TypeInfo + 'static, K: TypeInfo + 'static, L: TypeInfo + 'static, M: TypeInfo + 'static, N: TypeInfo + 'static, O: TypeInfo + 'static, P: TypeInfo + 'static, Q: TypeInfo + 'static,



impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R)
where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static, J: TypeInfo + 'static, K: TypeInfo + 'static, L: TypeInfo + 'static, M: TypeInfo + 'static, N: TypeInfo + 'static, O: TypeInfo + 'static, P: TypeInfo + 'static, Q: TypeInfo + 'static, R: TypeInfo + 'static,



impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S)
where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static, J: TypeInfo + 'static, K: TypeInfo + 'static, L: TypeInfo + 'static, M: TypeInfo + 'static, N: TypeInfo + 'static, O: TypeInfo + 'static, P: TypeInfo + 'static, Q: TypeInfo + 'static, R: TypeInfo + 'static, S: TypeInfo + 'static,



impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T> TypeInfo for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T)
where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static, J: TypeInfo + 'static, K: TypeInfo + 'static, L: TypeInfo + 'static, M: TypeInfo + 'static, N: TypeInfo + 'static, O: TypeInfo + 'static, P: TypeInfo + 'static, Q: TypeInfo + 'static, R: TypeInfo + 'static, S: TypeInfo + 'static, T: TypeInfo + 'static,



impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z> TypeInfo for MultiVersion<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z>
where A: TypeInfo + 'static, B: TypeInfo + 'static, C: TypeInfo + 'static, D: TypeInfo + 'static, E: TypeInfo + 'static, F: TypeInfo + 'static, G: TypeInfo + 'static, H: TypeInfo + 'static, I: TypeInfo + 'static, J: TypeInfo + 'static, K: TypeInfo + 'static, L: TypeInfo + 'static, M: TypeInfo + 'static, N: TypeInfo + 'static, O: TypeInfo + 'static, P: TypeInfo + 'static, Q: TypeInfo + 'static, R: TypeInfo + 'static, S: TypeInfo + 'static, T: TypeInfo + 'static, U: TypeInfo + 'static, V: TypeInfo + 'static, W: TypeInfo + 'static, X: TypeInfo + 'static, Y: TypeInfo + 'static, Z: TypeInfo + 'static,



type Identity = MultiVersion<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z>



fn type_info() -> Type



impl<AccountId> TypeInfo for StakerStatus<AccountId>
where Vec<AccountId>: TypeInfo + 'static, AccountId: TypeInfo + 'static,



type Identity = StakerStatus<AccountId>



fn type_info() -> Type



impl<AccountId, AccountIndex> TypeInfo for MultiAddress<AccountId, AccountIndex>
where AccountId: TypeInfo + 'static, AccountIndex: HasCompact + TypeInfo + 'static,



type Identity = MultiAddress<AccountId, AccountIndex>



fn type_info() -> Type



impl<AccountId, Balance> TypeInfo for Exposure<AccountId, Balance>
where Balance: HasCompact + TypeInfo + 'static, Vec<IndividualExposure<AccountId, Balance>>: TypeInfo + 'static, AccountId: TypeInfo + 'static,



type Identity = Exposure<AccountId, Balance>



fn type_info() -> Type



impl<AccountId, Balance> TypeInfo for ExposurePage<AccountId, Balance>
where Balance: HasCompact + TypeInfo + 'static, Vec<IndividualExposure<AccountId, Balance>>: TypeInfo + 'static, AccountId: TypeInfo + 'static,



type Identity = ExposurePage<AccountId, Balance>



fn type_info() -> Type



impl<AccountId, Balance> TypeInfo for IndividualExposure<AccountId, Balance>
where Balance: HasCompact + TypeInfo + 'static, AccountId: TypeInfo + 'static,



type Identity = IndividualExposure<AccountId, Balance>



fn type_info() -> Type



impl<Address, Call, Signature, ExtensionV0, const MAX_CALL_SIZE: usize, ExtensionOtherVersions> TypeInfo for UncheckedExtrinsic<Address, Call, Signature, ExtensionV0, ExtensionOtherVersions, MAX_CALL_SIZE>
where Address: StaticTypeInfo, Call: StaticTypeInfo, Signature: StaticTypeInfo, ExtensionV0: StaticTypeInfo, ExtensionOtherVersions: StaticTypeInfo,

Manual TypeInfo implementation because of custom encoding. The data is a valid encoded Vec<u8>, but requires some logic to extract the signature and payload.

See [UncheckedExtrinsic::encode] and [UncheckedExtrinsic::decode].



type Identity = UncheckedExtrinsic<Address, Call, Signature, ExtensionV0, ExtensionOtherVersions, MAX_CALL_SIZE>



fn type_info() -> Type



impl<Balance> TypeInfo for PagedExposureMetadata<Balance>
where Balance: HasCompact + MaxEncodedLen + TypeInfo + 'static,



type Identity = PagedExposureMetadata<Balance>



fn type_info() -> Type



impl<ExtensionV0, ExtensionOtherVersions> TypeInfo for ExtensionVariant<ExtensionV0, ExtensionOtherVersions>
where ExtensionV0: TypeInfo + 'static, ExtensionOtherVersions: TypeInfo + 'static,



type Identity = ExtensionVariant<ExtensionV0, ExtensionOtherVersions>



fn type_info() -> Type



impl<Header, Extrinsic> TypeInfo for Block<Header, Extrinsic>
where Header: TypeInfo + 'static, Vec<Extrinsic>: TypeInfo + 'static, Extrinsic: TypeInfo + 'static,



type Identity = Block<Header, Extrinsic>



fn type_info() -> Type



impl<Header, Extrinsic> TypeInfo for LazyBlock<Header, Extrinsic>
where Header: TypeInfo + 'static, PhantomData<Extrinsic>: TypeInfo + 'static, Extrinsic: TypeInfo + 'static,



type Identity = LazyBlock<Header, Extrinsic>



fn type_info() -> Type



impl<Idx> TypeInfo for Range<Idx>
where Idx: TypeInfo + 'static + PartialOrd + Debug,



type Identity = Range<Idx>



fn type_info() -> Type



impl<Idx> TypeInfo for RangeInclusive<Idx>
where Idx: TypeInfo + 'static + PartialOrd + Debug,



type Identity = RangeInclusive<Idx>



fn type_info() -> Type



impl<Info> TypeInfo for DispatchErrorWithPostInfo<Info>
where Info: Eq + PartialEq + Clone + Copy + Encode + Decode + Printable + TypeInfo + 'static,



type Identity = DispatchErrorWithPostInfo<Info>



fn type_info() -> Type



impl<Inner> TypeInfo for FakeDispatchable<Inner>
where Inner: TypeInfo + 'static,



type Identity = FakeDispatchable<Inner>



fn type_info() -> Type



impl<K, V> TypeInfo for BTreeMap<K, V>
where K: TypeInfo + 'static, V: TypeInfo + 'static,



type Identity = BTreeMap<K, V>



fn type_info() -> Type



impl<Keys, Proof> TypeInfo for GeneratedSessionKeys<Keys, Proof>
where Keys: TypeInfo + 'static, Proof: TypeInfo + 'static,



type Identity = GeneratedSessionKeys<Keys, Proof>



fn type_info() -> Type



impl<Number, Hash> TypeInfo for Header<Number, Hash>
where Number: Copy + Into<U256> + TryFrom<U256> + HasCompact + TypeInfo + 'static, Hash: Hash + 'static, <Hash as Hash>::Output: TypeInfo + 'static,



type Identity = Header<Number, Hash>



fn type_info() -> Type



impl<Reporter, Offender> TypeInfo for OffenceDetails<Reporter, Offender>
where Offender: TypeInfo + 'static, Vec<Reporter>: TypeInfo + 'static, Reporter: TypeInfo + 'static,



type Identity = OffenceDetails<Reporter, Offender>



fn type_info() -> Type



impl<SE> TypeInfo for AsTransactionExtension<SE>
where SE: SignedExtension + TypeInfo + 'static,



type Identity = AsTransactionExtension<SE>



fn type_info() -> Type



impl<T> TypeInfo for Cow<'static, T>
where T: ToOwned + TypeInfo + 'static + ?Sized,



type Identity = Cow<'static, T>



fn type_info() -> Type



impl<T> TypeInfo for Option<T>
where T: TypeInfo + 'static,



type Identity = Option<T>



fn type_info() -> Type



impl<T> TypeInfo for &T
where T: TypeInfo + 'static + ?Sized,



type Identity = T



fn type_info() -> Type



impl<T> TypeInfo for &mut T
where T: TypeInfo + 'static + ?Sized,



type Identity = T



fn type_info() -> Type



impl<T> TypeInfo for [T]
where T: TypeInfo + 'static,



type Identity = [T]



fn type_info() -> Type



impl<T> TypeInfo for Box<T>
where T: TypeInfo + 'static + ?Sized,



type Identity = T



fn type_info() -> Type



impl<T> TypeInfo for BinaryHeap<T>
where T: TypeInfo + 'static,



type Identity = BinaryHeap<T>



fn type_info() -> Type



impl<T> TypeInfo for BTreeSet<T>
where T: TypeInfo + 'static,



type Identity = BTreeSet<T>



fn type_info() -> Type



impl<T> TypeInfo for VecDeque<T>
where T: TypeInfo + 'static,



type Identity = [T]



fn type_info() -> Type



impl<T> TypeInfo for Rc<T>
where T: TypeInfo + 'static + ?Sized,



type Identity = T



fn type_info() -> Type



impl<T> TypeInfo for Arc<T>
where T: TypeInfo + 'static + ?Sized,



type Identity = T



fn type_info() -> Type



impl<T> TypeInfo for Vec<T>
where T: TypeInfo + 'static,



type Identity = [T]



fn type_info() -> Type



impl<T> TypeInfo for Compact<T>
where T: TypeInfo + 'static,



type Identity = Compact<T>



fn type_info() -> Type



impl<T, D> TypeInfo for TypeWithDefault<T, D>
where T: StaticTypeInfo, D: Get<T> + 'static,



type Identity = TypeWithDefault<T, D>



fn type_info() -> Type



impl<T, E> TypeInfo for Result<T, E>
where T: TypeInfo + 'static, E: TypeInfo + 'static,



type Identity = Result<T, E>



fn type_info() -> Type



impl<T, O> TypeInfo for BitVec<T, O>
where T: BitStore + TypeInfo + 'static, O: BitOrder + TypeInfo + 'static,



type Identity = BitVec<T, O>



fn type_info() -> Type



impl<T, const N: usize> TypeInfo for [T; N]
where T: TypeInfo + 'static,



type Identity = [T; N]



fn type_info() -> Type



impl<Xt> TypeInfo for Block<Xt>
where Vec<Xt>: TypeInfo + 'static, Xt: TypeInfo + 'static,



type Identity = Block<Xt>



fn type_info() -> Type



impl<const N: usize, T> TypeInfo for CryptoBytes<N, T>



type Identity = [u8; N]



fn type_info() -> Type



impl<const R: usize> TypeInfo for RingContext<R>



type Identity = RingContext<R>



fn type_info() -> Type



impl<const VERSION: u8, Extension> TypeInfo for PipelineAtVers<VERSION, Extension>
where Extension: TypeInfo + 'static,



type Identity = PipelineAtVers<VERSION, Extension>



fn type_info() -> Type

Implementors

Source

impl TypeInfo for DispatchClass

Source

impl TypeInfo for Pays

Source

impl TypeInfo for Never

Source

impl TypeInfo for SteppedMigrationError

Source

impl TypeInfo for ProcessMessageError



impl TypeInfo for TrieError

Source

impl TypeInfo for Select

Source

impl TypeInfo for UpgradeCheckSelect

Source

impl TypeInfo for Judgement

Source

impl TypeInfo for Statement

Source

impl TypeInfo for Truth

Source

impl TypeInfo for Social

Source

impl TypeInfo for LookupError

Source

impl TypeInfo for BalanceStatus

Source

impl TypeInfo for TransferStatus

Source

impl TypeInfo for ViewFunctionDispatchError



impl TypeInfo for frame_support::pallet_prelude::DispatchError



impl TypeInfo for InvalidTransaction



impl TypeInfo for TransactionSource



impl TypeInfo for TransactionValidityError



impl TypeInfo for UnknownTransaction

Source

impl TypeInfo for DispatchInfo

Source

impl TypeInfo for PostDispatchInfo



impl TypeInfo for CheckInherentsResult



impl TypeInfo for InherentData

Source

impl TypeInfo for PalletId

Source

impl TypeInfo for ContextualAlias

Source

impl TypeInfo for Disabled

Source

impl TypeInfo for Footprint

Source

impl TypeInfo for StorageInfo

Source

impl TypeInfo for ViewFunctionId



impl TypeInfo for RuntimeDbWeight



impl TypeInfo for Weight



impl TypeInfo for ValidTransaction



impl<'a, T, S> TypeInfo for BoundedSlice<'a, T, S>
where 'a: 'static, &'a [T]: TypeInfo + 'static, PhantomData<S>: TypeInfo + 'static, T: TypeInfo + 'static, S: TypeInfo + 'static,



type Identity = BoundedSlice<'a, T, S>

Source

impl<A, F, R, D, Fp> TypeInfo for FreezeConsideration<A, F, R, D, Fp>
where F: MutateFreeze<A> + 'static, F::Balance: TypeInfo + 'static, PhantomData<fn() -> (A, R, D, Fp)>: TypeInfo + 'static, A: 'static, R: 'static, D: 'static, Fp: 'static,

Source

type Identity = FreezeConsideration<A, F, R, D, Fp>

Source

impl<A, F, R, D, Fp> TypeInfo for HoldConsideration<A, F, R, D, Fp>
where F: MutateHold<A> + 'static, F::Balance: TypeInfo + 'static, PhantomData<fn() -> (A, R, D, Fp)>: TypeInfo + 'static, A: 'static, R: 'static, D: 'static, Fp: 'static,

Source

type Identity = HoldConsideration<A, F, R, D, Fp>

Source

impl<A, Fx, Rx, D, Fp> TypeInfo for LoneFreezeConsideration<A, Fx, Rx, D, Fp>
where PhantomData<fn() -> (A, Fx, Rx, D, Fp)>: TypeInfo + 'static, A: 'static, Fx: 'static, Rx: 'static, D: 'static, Fp: 'static,

Source

type Identity = LoneFreezeConsideration<A, Fx, Rx, D, Fp>

Source

impl<A, Fx, Rx, D, Fp> TypeInfo for LoneHoldConsideration<A, Fx, Rx, D, Fp>
where PhantomData<fn() -> (A, Fx, Rx, D, Fp)>: TypeInfo + 'static, A: 'static, Fx: 'static, Rx: 'static, D: 'static, Fp: 'static,

Source

type Identity = LoneHoldConsideration<A, Fx, Rx, D, Fp>

Source

impl<AccountId> TypeInfo for RawOrigin<AccountId>
where AccountId: TypeInfo + 'static,

Source

type Identity = RawOrigin<AccountId>

Source

impl<AccountId> TypeInfo for Admin<AccountId>
where PhantomData<AccountId>: TypeInfo + 'static, AccountId: TypeInfo + 'static,

Source

type Identity = Admin<AccountId>

Source

impl<AccountId> TypeInfo for Owner<AccountId>
where PhantomData<AccountId>: TypeInfo + 'static, AccountId: TypeInfo + 'static,

Source

type Identity = Owner<AccountId>

Source

impl<AssetId> TypeInfo for NativeOrWithId<AssetId>
where AssetId: Ord + TypeInfo + 'static,

Source

impl<B, OnDrop, OppositeOnDrop> TypeInfo for Imbalance<B, OnDrop, OppositeOnDrop>
where B: TypeInfo + 'static + Balance, PhantomData<(OnDrop, OppositeOnDrop)>: TypeInfo + 'static, OnDrop: HandleImbalanceDrop<B> + 'static, OppositeOnDrop: HandleImbalanceDrop<B> + 'static,

Source

type Identity = Imbalance<B, OnDrop, OppositeOnDrop>



impl<Balance> TypeInfo for WeightToFeeCoefficient<Balance>
where Balance: TypeInfo + 'static,

Source

impl<BlockNumber> TypeInfo for DispatchTime<BlockNumber>
where BlockNumber: TypeInfo + 'static,

Source

type Identity = DispatchTime<BlockNumber>

Source

impl<ConfigValue, Extra> TypeInfo for WithConfig<ConfigValue, Extra>
where ConfigValue: TypeInfo + 'static + ConfigValueMarker, Extra: TypeInfo + 'static,

Source

type Identity = WithConfig<ConfigValue, Extra>

Source

impl<Id, Balance> TypeInfo for IdAmount<Id, Balance>
where Id: TypeInfo + 'static, Balance: TypeInfo + 'static,

Source

type Identity = IdAmount<Id, Balance>

Source

impl<Inspect> TypeInfo for ConfigValue<Inspect>
where Inspect::Value: TypeInfo + 'static, Inspect: InspectStrategy + TypeInfo + 'static,



impl<K, V, S> TypeInfo for BoundedBTreeMap<K, V, S>
where BTreeMap<K, V>: TypeInfo + 'static, PhantomData<S>: TypeInfo + 'static, K: TypeInfo + 'static, V: TypeInfo + 'static, S: 'static,



type Identity = BoundedBTreeMap<K, V, S>

Source

impl<Params, ReportedId> TypeInfo for DeriveAndReportId<Params, ReportedId>
where Params: TypeInfo + 'static, PhantomData<ReportedId>: TypeInfo + 'static, ReportedId: TypeInfo + 'static,

Source

type Identity = DeriveAndReportId<Params, ReportedId>

Source

impl<Params, RuntimeCall> TypeInfo for Callback<Params, RuntimeCall>
where PhantomData<(Params, RuntimeCall)>: TypeInfo + 'static, Params: 'static, RuntimeCall: 'static,

Source

type Identity = Callback<Params, RuntimeCall>

Source

impl<T> TypeInfo for PerDispatchClass<T>
where T: TypeInfo + 'static,

Source

impl<T> TypeInfo for NoDrop<T>
where T: TypeInfo + 'static + Default,



impl<T> TypeInfo for PhantomData<T>

Source

impl<T, H> TypeInfo for Bounded<T, H>
where H::Output: TypeInfo + 'static, PhantomData<T>: TypeInfo + 'static, T: TypeInfo + 'static, H: Hash + TypeInfo + 'static,

Source

impl<T, Hash> TypeInfo for MaybeHashed<T, Hash>
where T: TypeInfo + 'static, Hash: TypeInfo + 'static,



impl<T, S> TypeInfo for BoundedBTreeSet<T, S>
where BTreeSet<T>: TypeInfo + 'static, PhantomData<S>: TypeInfo + 'static, T: TypeInfo + 'static, S: 'static,



impl<T, S> TypeInfo for BoundedVec<T, S>
where Vec<T>: TypeInfo + 'static, PhantomData<S>: TypeInfo + 'static, T: TypeInfo + 'static, S: 'static,



type Identity = BoundedVec<T, S>



impl<T, S> TypeInfo for WeakBoundedVec<T, S>
where Vec<T>: TypeInfo + 'static, PhantomData<S>: TypeInfo + 'static, T: TypeInfo + 'static, S: 'static,

Source

impl<T: TypeInfo + 'static> TypeInfo for WrapperKeepOpaque<T>

Source

impl<T: TypeInfo + 'static> TypeInfo for WrapperOpaque<T>

Source

impl<WitnessData> TypeInfo for Witness<WitnessData>
where PhantomData<WitnessData>: TypeInfo + 'static, WitnessData: TypeInfo + 'static,

Source

type Identity = Witness<WitnessData>